@@ -9,7 +9,7 @@ import peewee as pw
 # Package information
 # ===================
 
-__version__ = "1.4.6"
+__version__ = "1.4.9"
 __project__ = "peewee_migrate"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
@@ -34,4 +34,7 @@ class MigrateHistory(pw.Model):
 MIGRATE_TABLE = 'migratehistory'
 
 
-from .router import Migrator, Router # noqa
+from .router import Migrator, Router
+
+
+__all__ = 'Migrator', 'Router'
